@@ -145,7 +145,7 @@ dlg_ask_password__common (FrWindow       *window,
 
 	filename = _g_file_get_display_basename (file);
 	/* Translators: %s is a filename */
-	message = g_strdup_printf (_("Password required for \"%s\""), filename);
+	message = g_strdup_printf (_("Password required for “%s”"), filename);
 	gtk_label_set_label (GTK_LABEL (GET_WIDGET ("title_label")), message);
 
 	_gtk_entry_use_as_password_entry (GTK_ENTRY (data->password_entry));
