@@ -61,6 +61,7 @@
 /* The capabilities are computed automatically in
  * compute_supported_archive_types() so it's correct to initialize to 0 here. */
 FrMimeTypeDescription mime_type_desc[] = {
+	{ "application/epub+zip",               ".epub",     0 },
 	{ "application/x-7z-compressed",        ".7z",       0 },
 	{ "application/x-7z-compressed-tar",    ".tar.7z",   0 },
 	{ "application/x-ace",                  ".ace",      0 },
@@ -75,6 +76,7 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-cbr",                  ".cbr",      0 },
 	{ "application/x-cbz",                  ".cbz",      0 },
 	{ "application/x-cd-image",             ".iso",      0 },
+	{ "application/x-chrome-extension",	".crx",      0 },
 	{ "application/x-compress",             ".Z",        0 },
 	{ "application/x-compressed-tar",       ".tar.gz",   0 },
 	{ "application/x-cpio",                 ".cpio",     0 },
@@ -129,8 +131,10 @@ FrExtensionType file_ext_type[] = {
 	{ ".cbz", "application/x-cbz" },
 	{ ".click", "application/x-deb" },
 	{ ".cpio", "application/x-cpio" },
+	{ ".crx", "application/x-chrome-extension" },
 	{ ".deb", "application/x-deb" },
 	{ ".ear", "application/x-ear" },
+	{ ".epub", "application/epub+zip" },
 	{ ".exe", "application/x-ms-dos-executable" },
 	{ ".gz", "application/x-gzip" },
 	{ ".iso", "application/x-cd-image" },
